capture log close
log using ers1-data-01-cleaning, replace text

// Clean and Label Raw Data
// ERS - Escalation Study 1 - Fall 2013

version 13.1
clear all
macro drop _all
set linesize 80

local pgm "ers1-data-01-cleaning"
local prj "Escalation Study 1"
local dte "2013-11-15"
local who "trenton mize"
local tag "`pgm' `who' `dte'"

**Imported data from Excel CSV file

use "- Data\ers1-01-raw_data", clear


******************************************************************
//  #1 - Sort Data and Create Unique Subject ID
******************************************************************

sort 	session Subject Period
gen  	ID = Subject + 6*(session - 101) + 100
drop if Period < 1 



******************************************************************
// # 2 - Rename and Label Variables
******************************************************************

clonevar	hicost=role
lab var		hicost "High Cost Condition"
recode		hicost 1=0 2=1
lab define	hilab 1"Yes_75" 0"No_25"
lab values 	hicost hilab

**Drop unneeded vars
drop		role other rep1-rep5 roledisplay _1539

destring	scoreinc challenge lastact Pgender latino race age yrschool major ///
			reptotal Period outcome, replace

lab var		scoreinc "Paid to Increase Score"
lab define 	yesno 1"Yes" 0"No"
lab values	scoreinc yesno

lab var		challenge "Challenged on Round"
lab values	challenge yesno

lab var		outcome "Outcome in Round"
lab define 	outlab 	1"Both Defer" 2"Defer, Part Chall" 3"Chall, Part Defers" ///
					4"Lost Chall" 5"Won Chall"
lab values	outcome outlab

clonevar	subject=Subject
clonevar	period=Period

*Create Time Block Var
clonevar 	timeblk=period
lab var		timeblk "Time in 5 Period Blocks"
recode		timeblk 1/5=1 6/10=2 11/15=3 16/20=4 21/25=5 26/30=6 31/35=7
tab			period timeblk

lab var		lastact "Aggressive Last Meeting?"
lab define	agglab 0"Not_Agg" 1"Aggress"
lab values	lastact agglab
*Recode "lastact" as missing for the first 5 rounds (1st time block)
replace 	lastact = . if timeblk == 1
tab 		timeblk lastact

*Recode repotatl as missing for first time block (before they had 5 rounds /
* full information)
rename		reptotal reptotalA
lab var		reptotalA "reptotal with time 1"

clonevar	reptotal = reptotalA
replace		reptotal = . if timeblk == 1
lab var		reptotal "Times Escalated Last 5 Rounds"
tab 		timeblk reptotal

lab var		profit "Total Profit"

lab var		profitrd "Profit in Round"

egen 		female= total(Pgender), by(ID)
lab var		female "Female=1"
recode		female 1=0 2=1
lab values	female yesno
tab			female, m

lab var 	latino "Latino=1"
recode		latino 1=1 2=0
lab values 	latino yesno

lab var		race "Race"
lab define 	racelab 1"White" 2"Black" 3"Asian" 4"Other"
lab values 	race racelab

lab var 	age "Age in Years"

lab var 	yrschool "Year in School"
lab define 	schlab 	1"1st-Freshman" 2"2nd-Soph" 3"3rd-Junio" 4"4th-Senior" ///
					5"Grad Student"
lab values 	yrschool schlab

lab var		major "College Major"
lab define 	majorlab 1"Econ" 2"SocSci" 3"Science" 4"Business" 5"ArtMusic" 6"Other"
lab values	major majorlab

drop		Subject Period Pgender


**Post-Experimental Questionnaire

**Baumeister Self-Regulation Scale
clonevar	SR1habits=postquiz1
lab var		SR1habits "1 Self-Regulation Q"

clonevar	SR2distract=postquiz2
lab var		SR2distract "2 Self-Regulation Q"

clonevar	SR3innap=postquiz3
lab var		SR3innap "3 Self-Regulation Q"

clonevar	SR4fun=postquiz4
lab var		SR4fun "4 Self-Regulation Q"

clonevar	SR5tempt=postquiz5
lab var		SR5tempt "5 Self-Regulation Q"

clonevar 	SR6disc=postquiz6
lab var		SR6disc "6 Self-Regulation Q"

clonevar	SR7pleas=postquiz7
lab var		SR7pleas "7 Self-Regulation Q"

clonevar	SR8regret=postquiz8
lab var		SR8regret "8 Self-Regulation Q"

clonevar	SR9stop=postquiz9
lab var		SR9stop "9 Self-Regulation Q"

clonevar	SR10act=postquiz10
lab var		SR10 "10 Self-Regulation Q"

**Honor Code Items
clonevar	HC11force=postquiz11
lab var		HC11force "11 Honor Code Q"

clonevar	HC12tough=postquiz12
lab var		HC12tough "12 Honor Code Q"

clonevar	HC13even=postquiz13
lab var		HC13even "13 Honor Code Q"

clonevar	HC14fair=postquiz14
lab var		HC14fair "14 Honor Code Q"

clonevar	HC15aggr=postquiz15
lab var		HC15aggr "15 Honor Code Q"

clonevar	HC16intim=postquiz16
lab var		HC16intim "16 Honor Code Q"


**Agression Items
clonevar	AG17angry=postquiz17
lab var		AG17angry "Angry at You"

clonevar	AG18crit=postquiz18
lab var		AG18crit "Criticized by Others"

clonevar	AG19face=postquiz19
lab var		AG19 "You Criticize Others"

clonevar	AG20back=postquiz20
lab var		AG20back "Bad Things Said About You"

clonevar	AG21insult=postquiz21
lab var		AG21insult "You Insult Someone"

clonevar	AG22shout=postquiz22
lab var		AG22shout "Insult Someone Know"

clonevar	AG23no=postquiz23
lab var		AG23no "Insult Someone Didn't Know"

clonevar	AG24hit=postquiz24
lab var		AG24hit "Hit Someone Know"

clonevar	AG25slap=postquiz25
lab var		AG25slap "Hit Someone Didn't Know"

clonevar	AG26obj=postquiz26
lab var		AG26obj "Hit Someone w Object"	

destring AG* SR* HC*, replace

recode		AG17 AG18 AG19 (1=4) (2=3) (3=2) (4=1) (5=.)
recode		AG20-AG26 (1=6) (2=5) (3=4) (4=3) (5=2) (6=1) (7=.)

lab define	aglab1 1"Never" 2"Rarely" 3"Occasionally" 4"Frequently"
lab values	AG17-AG19 aglab1

lab define	aglab2  1"Weekly" 2"Twice a Month" 3"Monthly" 4"3-4 Per Year" ///
					5"1-2 Per Year" 6"Never"
lab values	AG20-AG26 aglab2	



******************************************************************
//  #3 - Drop Participants due to Suspicion
******************************************************************

tab 	female, m

*Following Ps were suspcious per RA assessment and confirmed by TDM
*Starting N=120, dropping 11, or 9.2% of Ps
drop if ID== 128
drop if ID== 131
drop if ID== 136
drop if ID== 140
drop if ID== 160
drop if ID== 166
drop if ID== 169
drop if ID== 179
drop if ID== 182
drop if ID== 187
drop if ID== 196



******************************************************************
// #4 - Add value labels to survey items
******************************************************************

lab define	likert 1"Strong_Disagree" 2"Disagree" 3"Agree" 4"Strong_Agree" 
local likvars "SR1habits SR2distract SR3innap SR4fun SR5tempt SR6disc"
local likvars "`likvars' SR7pleas SR8regret SR9stop SR10act HC11force"
local likvars "`likvars' HC12tough HC13even HC14fair HC15aggr HC16intim"


foreach v in `likvars' {
		lab values `v' likert
		}

*Drop unneccessary vars
drop 	earn* esccost* had* oppchallenge* ownid* partic* ///
		profit* profitrd* subject* postquiz*

** Save and Label Long Dataset

compress
label 	data "ers1-02-clean.dta | Cleaned Long Data `prj' | `dte'"
note: 	ers1-02-clean-long | Cleaned Long Data | `tag'
datasignature set, reset
saveold "- Data\ers1-02-clean-long", replace


log close
exit

NOTES:
