capture log close
log using ers1-data-03-win_lost, replace text

// Create Win/Lost (Outcome) of Last Interaction Vars
// ERS1 - Escalation Study 1

version 13.1
clear all
macro drop _all
set more off
set linesize 80

local pgm "ers1-data-03-win_lost"
local prj "Escalation Study 1"
local dte "2016-10-27"
local who "trenton mize"
local tag "`pgm' `who' `dte'"


******************************************************************
// #0 - Adding roundscript to each row for P in Excel
******************************************************************
*NOTE: Uncomment to recreate from original excel sheet
*	Leave commented to start from Stata file

/*
use "- Data\ers1-04-long", clear 

export excel using "ers1-temp", firstrow(variables) nolabel replace

import excel "C:\Users\tdmize\Dropbox\Research Projects\ERS - Escalation & Reputation Systems\Work\Data & Analysis\ers1-temp-02.xls", ///
		sheet("Sheet1") firstrow clear

save "- Data\ers1-05-long-win_lost", replace
*/


/////////////////////
// Trent's Version //
/////////////////////

********************************************************************		
// #1 - Assign Partner IDs
********************************************************************		
use "- Data\ers1-05-long-win_lost", clear


gen 	partner = .

replace partner = 1 if roundscript ==1 & (period ==3 | period ==8 | ///
		period ==12 | period == 20 | period ==21 |period ==28 | period ==35)
replace partner = 2 if roundscript ==1 & (period ==4 | period ==7 | ///
		period == 13 | period ==18 | period == 24|period == 26| period ==31)
replace partner = 3 if roundscript ==1 & (period ==2 | period ==6 | ///
		period == 11| period == 19 | period == 23|period == 29| period ==32)
replace partner = 4 if roundscript ==1 & (period == 5| period == 9| ///
		period == 15| period == 16| period == 25 |period == 30| period ==33)
replace partner = 5 if roundscript ==1 & (period == 1| period == 10| ///
		period == 14| period == 17 | period == 22|period == 27| period ==34)

replace partner = 1 if roundscript ==2 & (period == 2| period == 10| ///
		period ==13 | period == 19 | period == 23|period == 26| period ==35)
replace partner = 2 if roundscript ==2 & (period == 3| period == 6| ///
		period == 14 | period == 20 | period == 24|period == 28| period ==34)
replace partner = 3 if roundscript ==2 & (period == 1| period == 7| ///
		period == 15 | period == 16 | period == 22|period == 30| period ==33)
replace partner = 4 if roundscript ==2 & (period == 4| period == 9| ///
		period == 11 | period == 17 | period ==  25|period == 27| period ==32)
replace partner = 5 if roundscript ==2 & (period == 5| period == 8| ///
		period == 12 | period == 18| period == 21 |period == 29| period == 31 )

fre  	partner		
		

********************************************************************		
// #2 - Get outcome of past interaction and save in new variable
********************************************************************		

gen 		outcome2 = .
lab var		outcome2 "Outcome of Last Interaction"
lab values 	outcome2 outlab
lab values	outcome outlab

gen			outcomeTB1 = .
replace		outcomeTB1 = outcome if timeblk == 1
gen			outcomeTB2 = .
replace		outcomeTB2 = outcome if timeblk == 2
gen			outcomeTB3 = .
replace		outcomeTB3 = outcome if timeblk == 3
gen			outcomeTB4 = .
replace		outcomeTB4 = outcome if timeblk == 4
gen			outcomeTB5 = .
replace		outcomeTB5 = outcome if timeblk == 5
gen			outcomeTB6 = .
replace		outcomeTB6 = outcome if timeblk == 6
gen			outcomeTB7 = .
replace		outcomeTB7 = outcome if timeblk == 7

sort  ID partner timeblk
order ID partner timeblk period scoreinc challenge lastact outcome ///
	outcome2 outcomeTB1 outcomeTB2 outcomeTB3 outcomeTB4 outcomeTB5 ///
	outcomeTB6 outcomeTB7
	
forvalues i = 1/7 {
	bysort ID partner: carryforward outcomeTB`i', replace
	}


forvalues i = 1/5 {
	replace outcome2 = outcomeTB1 if timeblk == 2 & partner == `i'
	replace outcome2 = outcomeTB2 if timeblk == 3 & partner == `i'
	replace outcome2 = outcomeTB3 if timeblk == 4 & partner == `i'
	replace outcome2 = outcomeTB4 if timeblk == 5 & partner == `i'
	replace outcome2 = outcomeTB5 if timeblk == 6 & partner == `i'
	replace outcome2 = outcomeTB6 if timeblk == 7 & partner == `i'
	}
	
fre 	outcome2
	
	
	
********************************************************************
// #3 - Create Binary Variables for Outcome of last interaction
********************************************************************

gen 	bothdefer2 = 0
lab var bothdefer2 "Both Deferred Last Meeting"
replace bothdefer2 =1 if outcome2 ==1

gen 	unidefer2 =0 
lab var unidefer2 "Defer, Part Chall Last Meeting"
replace unidefer2 =1 if outcome2 ==2

gen 	unichal2 = 0
lab var	unichal2 "Chall, Part Defer Last Meeting"
replace unichal2 =1 if outcome2 ==3

gen 	lose2 =0
lab var	lose2 "Lost Chall Last Meeting"
replace lose2 =1 if outcome2 ==4

gen 	win2 =0
lab var	win2 "Won Chall Last Meeting"
replace win2 =1 if outcome2 ==5 



********************************************************************
// #4 - Save and Label Data
********************************************************************

compress
label 	data "ers1-06-long-win_lost.dta | Outcome of Last Interaction Dataset `prj' | `dte'"
note: 	"- Data\ers1-06-long-win_lost" | Outcome of Last Interaction Dataset | `tag'
datasignature set, reset
saveold "- Data\ers1-06-long-win_lost", replace



log close
exit

NOTES:

*Below is Steve's original version of the code from a different paper
*NOTE: Leads to same coding as Trent's version above

/*
/////////////////////
// Steve's Version //
/////////////////////	


// #1 - Assign Partner IDs

gen str partner ="x"

replace partner = "a" if roundscript ==1 & (period ==3 | period ==8 | ///
		period ==12 | period == 20 | period ==21 |period ==28 | period ==35)
replace partner = "b" if roundscript ==1 & (period ==4 | period ==7 | ///
		period == 13 | period ==18 | period == 24|period == 26| period ==31)
replace partner = "c" if roundscript ==1 & (period ==2 | period ==6 | ///
		period == 11| period == 19 | period == 23|period == 29| period ==32)
replace partner = "e" if roundscript ==1 & (period == 5| period == 9| ///
		period == 15| period == 16| period == 25 |period == 30| period ==33)
replace partner = "f" if roundscript ==1 & (period == 1| period == 10| ///
		period == 14| period == 17 | period == 22|period == 27| period ==34)

replace partner = "a" if roundscript ==2 & (period == 2| period == 10| ///
		period ==13 | period == 19 | period == 23|period == 26| period ==35)
replace partner = "b" if roundscript ==2 & (period == 3| period == 6| ///
		period == 14 | period == 20 | period == 24|period == 28| period ==34)
replace partner = "c" if roundscript ==2 & (period == 1| period == 7| ///
		period == 15 | period == 16 | period == 22|period == 30| period ==33)
replace partner = "e" if roundscript ==2 & (period == 4| period == 9| ///
		period == 11 | period == 17 | period ==  25|period == 27| period ==32)
replace partner = "f" if roundscript ==2 & (period == 5| period == 8| ///
		period == 12 | period == 18| period == 21 |period == 29| period == 31 )

		
// #2 - Get outcome of past interaction and save in new variable
sort 	ID timeblk period
by 		ID timeblk: gen num = _n

sort 	ID period

gen 		outcome2=.
lab var		outcome2 "Outcome of Last Interaction"
lab values 	outcome2 outlab
lab values	outcome outlab

sum 	ID
local 	a = r(max)

foreach i of numlist 1/`a' {
	local d = 35*`i'-29
	local e = 35*`i'

	foreach j of numlist `d'/`e' {
		local b = num in `j'
		local c = `b'+4
		foreach k of numlist `b'/`c' {
			local g = `j'-`k'
			local f = outcome in `g'
			local x = `j'-`k'
			local h = partner in `x'  
			replace outcome2 = `f' if partner == "`h'" in `j'
		}
	}
}

*/
