capture log close
log using ers1-models-01-descriptives, replace text

// Descriptive Statistics
// ERS1 - Escalation Study # 1

version 13.1
clear all
macro drop _all
set more off
set linesize 80

local pgm "ers1-models-01-descriptives"
local prj "ERS1 - Escalation Study 1"
local dte "2013-11-16"
local who "trenton mize"
local tag "`pgm' `who' `dte'"


* Long Dataset 
use "- Data\ers1-03-w_scales-long", clear


*************************************************************
// #1 - Descriptive Statistics
*************************************************************

*Raw Totals for Challenging and Increasing Competitive Ability
local dvs "challenge scoreinc"
foreach v in `dvs' {
		di "Hi Cost Condition"
		sum `v' if hicost==1
		di "Medium Cost Condition"
		sum `v' if hicost==0
		di "Partner Aggressive Last Interaction"
		sum `v' if lastact==1
		di "Partner NOT Aggressive Last Interaction"
		sum `v' if lastact==0
		}

**Charts and Tables are created in ers1-tables_graphs.xlsx		
tabstat challenge if hicost==1, by(lastact)
tabstat challenge if hicost==0, by(lastact)	

tabstat scoreinc  if hicost==1, by(lastact)
tabstat scoreinc  if hicost==0, by(lastact)	

tabstat	challenge if  scoreinc==1 & hicost==0, by(lastact)
tabstat	challenge if  scoreinc==0 & hicost==0, by(lastact)

tabstat	challenge if  scoreinc==1 & hicost==1, by(lastact)
tabstat	challenge if  scoreinc==0 & hicost==1, by(lastact)


			
**Challenging and Increasing CA by Partner's Reputation		
tabstat challenge if 	hicost==1, by(reptotal)
tabstat challenge if 	hicost==0, by(reptotal)
tabstat scoreinc  if 	hicost==1, by(reptotal)
tabstat scoreinc  if 	hicost==0, by(reptotal)



*************************************************************
// #2 - Time Effects
*************************************************************

tabstat challenge, by(timeblk)
tabstat scoreinc, by(timeblk)

tabstat challenge if hicost==1, by(timeblk)
tabstat challenge if hicost==0, by(timeblk)
tabstat scoreinc  if hicost==1, by(timeblk)
tabstat scoreinc  if hicost==0, by(timeblk)

tabstat challenge if lastact==1, by(timeblk)
tabstat challenge if lastact==0, by(timeblk)
tabstat scoreinc  if lastact==1, by(timeblk)
tabstat scoreinc  if lastact==0, by(timeblk)

tabstat challenge if lastact==1 & hicost==0, by(timeblk)
tabstat challenge if lastact==0 & hicost==0, by(timeblk)
tabstat challenge if lastact==1 & hicost==1, by(timeblk)
tabstat challenge if lastact==0 & hicost==1, by(timeblk)

tabstat scoreinc if lastact==1 & hicost==0, by(timeblk)
tabstat scoreinc if lastact==0 & hicost==0, by(timeblk)
tabstat scoreinc if lastact==1 & hicost==1, by(timeblk)
tabstat scoreinc if lastact==0 & hicost==1, by(timeblk)



**Calculate basic correlations b/w Survey Scales and Behavior
pwcorr 	challenge scoreinc SRscale HCscale AGscale, sig



*************************************************************
// #3 - Estimate models and make predictions to get SEs for figures
*************************************************************

*	Looking at Condition X Partner Aggression
xtset ID

xtlogit challenge i.hicost##i.lastact i.timeblk, nolog or
mtable, at(hicost=(0 1) lastact=(0 1)) stat(est se) predict(pu0)

xtlogit scoreinc i.hicost##i.lastact i.timeblk, nolog or
mtable, at(hicost=(0 1) lastact=(0 1)) stat(est se) predict(pu0)


* Wide Dataset
use "- Data\ers1-03-w_scales-wide", clear

// # - Descriptives by Condition

*Raw Totals for Challenging and Increasing Competitive Ability
local dvs "chaltot sinctot"
foreach v in `dvs' {
		di "Hi Cost Condition"
		sum `v' if hicost_==1
		di "Medium Cost Condition"
		sum `v' if hicost_==0
		}





log close
exit

NOTES:

