capture log close
log using ers1-models-04-graphs, replace text

// Graphs for Paper
// ERS1 - Escalation Study # 1

version 	13.1
clear 		all
macro drop 	_all
set more 	off
set scheme 	s1color
set 		linesize 80

local pgm "ers1-models-04-graphs"
local prj "ERS1 - Escalation Study 1"
local dte "2016-09-27"
local who "trenton mize"
local tag "`pgm' `who' `dte'"

**Long Dataset
use "- Data\ers1-03-w_scales-long", clear


**************************************************************
// #1 - Nice bar charts for presentation in paper
**************************************************************
*Create a condition variable which is cost X partner aggression
gen 	cond = .
lab var	cond "Condition"
replace cond = 1 if hicost == 0 & lastact == 0
replace cond = 2 if hicost == 0 & lastact == 1
replace cond = 3 if hicost == 1 & lastact == 0
replace cond = 4 if hicost == 1 & lastact == 1

xtset ID

* Get SEs of estimates 
qui xtlogit challenge i.hicost##i.lastact timeblk, nolog or
mtable, at(hicost=(0 1) lastact=(0 1)) stat(est se) decimal(3) predict(pu0)

qui xtlogit scoreinc i.hicost##i.lastact timeblk, nolog or
mtable, at(hicost=(0 1) lastact=(0 1)) stat(est se) decimal(3) predict(pu0)


* Collapse to get data in correct form
* NOTE: Recoding to be predicted probabilities instead of proportions
collapse 	(mean) 	prchal = challenge ///
			(mean) 	princ  = scoreinc ///
			, by(cond)
			
replace 	prchal = .731 if cond == 1
replace		prchal = .704 if cond == 2
replace		prchal = .585 if cond == 3
replace		prchal = .454 if cond == 4

replace 	princ = .348 if cond == 1
replace		princ = .455 if cond == 2
replace		princ = .043 if cond == 3
replace		princ = .096 if cond == 4


*Add a gap in the condition variable for a space in the graphs
recode cond 1=1 2=2 	3=4 4=5



// Challenging // 

* Create vars for the SEs		
gen 	prUL = .
replace prUL = prchal + 0.041 if cond == 1
replace prUL = prchal + 0.043 if cond == 2
replace prUL = prchal + 0.052 if cond == 4
replace prUL = prchal + 0.053 if cond == 5

gen 	prLL = .
replace prLL = prchal - 0.041 if cond == 1
replace prLL = prchal - 0.043 if cond == 2
replace prLL = prchal - 0.052 if cond == 4
replace prLL = prchal - 0.053 if cond == 5


twoway 	(bar prchal cond if cond == 1, color(blue)) ///
		(bar prchal cond if cond == 2, color(gold)) ///
		(bar prchal cond if cond == 4, color(blue)) ///
		(bar prchal cond if cond == 5, color(gold)) ///
		(rcap prUL prLL cond, lwidth(medthick) lcolor(gs6)), ///
		ylab(0(0.1)1, nogrid) legend(row(1) ///
		order(1 "Not Aggressive" 2 "Aggressive")) ///
		xlabel(1.5 "Medium Cost" 4.5 "High Cost", noticks) ///
		ytitle("Pr(Challenge)", size(medium)) xtitle(" ") ///
		graphregion(color(white)) plotregion(style(none))
	
		graph save "- Graphs\ers1-bar_chart-Challenge", replace
		graph export "- Graphs\ers1-bar_chart-Challenge.emf", replace


	
// Escalating // 

* Create vars for the SEs		
drop	prUL prLL

gen 	prUL = .
replace prUL = princ + 0.035 if cond == 1
replace prUL = princ + 0.038 if cond == 2
replace prUL = princ + 0.009 if cond == 4
replace prUL = princ + 0.017 if cond == 5

gen 	prLL = .
replace prLL = princ - 0.035 if cond == 1
replace prLL = princ - 0.038 if cond == 2
replace prLL = princ - 0.009 if cond == 4
replace prLL = princ - 0.017 if cond == 5


twoway 	(bar princ cond if cond == 1, color(blue)) ///
		(bar princ cond if cond == 2, color(gold)) ///
		(bar princ cond if cond == 4, color(blue)) ///
		(bar princ cond if cond == 5, color(gold)) ///
		(rcap prUL prLL cond, lwidth(medthick) lcolor(gs6)), ///
		ylab(0(0.1)1, nogrid) legend(row(1) ///
		order(1 "Not Aggressive" 2 "Aggressive")) ///
		xlabel(1.5 "Medium Cost" 4.5 "High Cost", noticks) ///
		ytitle("Pr(Escalate)", size(medium)) xtitle(" ") ///
		graphregion(color(white)) plotregion(style(none))
	
		graph save "- Graphs\ers1-bar_chart-Escalate", replace
		graph export "- Graphs\ers1-bar_chart-Escalate.emf", replace
		

		
		
***************************************************************
// #2 - Figures for Effects over Time
***************************************************************

use "- Data\ers1-03-w_scales-long", clear
xtset 	ID 

xtlogit scoreinc i.hicost##i.lastact reptotal i.timeblk, nolog or
est store m1

*High cost condition predictions
mgen, at(hicost=(1) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prhi) predname(esc) predict(pu0)
*Low cost condition predictions
mgen, at(hicost=(0) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prlo) predname(esc) predict(pu0)

lab var prhiesc "High Cost"
lab var prloesc "Medium Cost"


graph twoway ///
	(connected prloesc prhiesc prhitimeblk, ///
	lwid(medium medium) msize(vlarge vlarge) msym(s o) ///
	mcol(red blue) lcol(red blue)), ///
	ytitle("Pr(Escalate)") ylab(, nogrid) xtitle("Time Block") ///
	xlab(2(1)7) ylab(0(0.2)1) ///
	graphregion(color(white)) plotregion(style(none))
	
	graph save		"- Graphs\ers1-prob_escalate_time", replace		
	graph export	"- Graphs\ers1-prob_escalate_time.emf", replace	

		
		
// Separate out predictions by partner aggression //
est restore m1		
		
*High cost, aggressive partner predictions
mgen, at(hicost=(1) lastact=(1) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prhiag) predname(esc) predict(pu0)
*High cost, non-aggressive partner predictions
mgen, at(hicost=(1) lastact=(0) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prhino) predname(esc) predict(pu0)
*Low cost, aggressive partner predictions
mgen, at(hicost=(0) lastact=(1) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prloag) predname(esc) predict(pu0)
*Low cost, non-aggressive partner predictions
mgen, at(hicost=(0) lastact=(0) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prlono) predname(esc) predict(pu0)

lab var prhiagesc "High Cost, Agressive Partner"
lab var prhinoesc "High Cost, Non-Agressive Partner"
lab var prloagesc "Medium Cost, Aggressive Partner"
lab var prlonoesc "Medium Cost, Non-Aggressive Partner"


graph twoway ///
	(connected prloagesc prlonoesc prhiagesc prhinoesc prhinotimeblk, ///
	lwid(medium medium medium medium) msize(vlarge vlarge vlarge vlarge) ///
	msym(s t o d) ///
	mcol(cranberry red dknavy blue) lcol(cranberry red dknavy blue)), ///
	ytitle("Pr(Escalate)") ylab(, nogrid) xtitle("Time Block") ///
	xlab(2(1)7) ylab(0(0.2)1) legend(region(lstyle(none))) ///
	graphregion(color(white)) plotregion(style(none))
	
	graph save		"- Graphs\ers1-prob_escalate_time-lastact", replace		
	graph export	"- Graphs\ers1-prob_escalate_time-lastact.emf", replace	
	
	

	
*****************	
// Challenging //
*****************
drop pr* 

xtlogit challenge i.hicost##i.lastact reptotal i.timeblk, nolog or
est store m2

*High cost condition predictions
mgen, at(hicost=(1) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prhi) predname(chal) predict(pu0)
*Low cost condition predictions
mgen, at(hicost=(0) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prlo) predname(chal) predict(pu0)

lab var prhichal "High Cost"
lab var prlochal "Medium Cost"


graph twoway ///
	(connected prlochal prhichal prhitimeblk, ///
	lwid(medium medium) msize(vlarge vlarge) msym(s o) ///
	mcol(red blue) lcol(red blue)), ///
	ytitle("Pr(Escalate)") ylab(, nogrid) xtitle("Time Block") ///
	xlab(2(1)7) ylab(0(0.2)1) ///
	graphregion(color(white)) plotregion(style(none))
	
	graph save		"- Graphs\ers1-prob_chal_time", replace		
	graph export	"- Graphs\ers1-prob_chal_time.emf", replace	

		
		
// Separate out predictions by partner aggression //
est restore m2		
		
*High cost, aggressive partner predictions
mgen, at(hicost=(1) lastact=(1) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prhiag) predname(chal) predict(pu0)
*High cost, non-aggressive partner predictions
mgen, at(hicost=(1) lastact=(0) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prhino) predname(chal) predict(pu0)
*Low cost, aggressive partner predictions
mgen, at(hicost=(0) lastact=(1) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prloag) predname(chal) predict(pu0)
*Low cost, non-aggressive partner predictions
mgen, at(hicost=(0) lastact=(0) timeblk=(2 3 4 5 6 7)) replace ///
		stub(prlono) predname(chal) predict(pu0)

lab var prhiagchal "High Cost, Agressive Partner"
lab var prhinochal "High Cost, Non-Agressive Partner"
lab var prloagchal "Medium Cost, Aggressive Partner"
lab var prlonochal "Medium Cost, Non-Aggressive Partner"


graph twoway ///
	(connected prloagchal prlonochal prhiagchal prhinochal prhinotimeblk, ///
	lwid(medium medium medium medium) msize(vlarge vlarge vlarge vlarge) ///
	msym(s t o d) ///
	mcol(cranberry red dknavy blue) lcol(cranberry red dknavy blue)), ///
	ytitle("Pr(Challenge)") ylab(, nogrid) xtitle("Time Block") ///
	xlab(2(1)7) ylab(0(0.2)1) legend(region(lstyle(none))) ///
	graphregion(color(white)) plotregion(style(none))
	
	graph save		"- Graphs\ers1-prob_chal_time-lastact", replace		
	graph export	"- Graphs\ers1-prob_chal_time-lastact.emf", replace			
		
		
		
log close
exit

NOTES: 

* A nice tutorial on making bar charts like this in Stata:
* http://www.ats.ucla.edu/stat/stata/faq/barcap.htm		
		
