capture log close
log using ers2-data-02-scale_creation, replace text

// Create Scales from Survey Questions, and Total Challenge and ScoreInc vars
// ERS2 - Escalation Study 2

version 	13.1
clear 		all
macro drop 	_all
set more 	off
set 		linesize 80

local pgm "ers2-data-02-scale_creation"
local prj "Escalation Study 2"
local dte "2014-04-06"
local who "trenton mize"
local tag "`pgm' `who' `dte'"
local use "ers2-02-clean"
local sav "ers2-03-w_scales"


use "- Data\ers2-02-clean-long", clear


****************************************************************
//  #1 - Create scales and calculate Cronbach's Alpha for Survey Measures
****************************************************************

* Baumeister Self-Regulation Questions
alpha 	SR*
egen 	SRscale2 = ///
		mean(SR1habits+SR2distract+SR3innap+SR4fun+SR5tempt+SR6disc+SR7pleas+ ///
		SR8regret+SR9stop+SR10act) ///
		, by(ID)
gen		SRscale = SRscale2/10		
lab var SRscale "Self-Regulation Scale"

* Honor Code Items
alpha 	HC*
egen 	HCscale2 = ///
		mean(HC11force+HC12tough+HC13even+HC14fair+HC15aggr+HC16intim) ///
		, by(ID)
gen		HCscale = HCscale2/6	
lab var HCscale "Honor Code Scale"


* Experience of Aggressive Interactions
alpha 	AG*
egen 	AGscale2 = ///
		mean(AG17angry+AG18crit+AG19face+AG20back+AG21insult+AG22shout+ ///
		AG23no+AG24hit+AG25slap+AG26obj) ///
		, by(ID)
gen		AGscale = AGscale2/10	
lab var AGscale "Aggression Scale"



****************************************************************
// #2 - Create sub-aggression scales
****************************************************************

tab1 AG*, m

* Verbal Perpetration
alpha 	AG19face AG22shout AG23no
egen 	AGscale_Verbal2 = mean(AG19face+AG22shout+AG23no) , by(ID)
gen		AGscale_Verbal = AGscale2/3	
lab var AGscale_Verbal "Verbal Aggression Scale"

*Physical Perpetration
alpha 	AG24hit AG25slap
egen 	AGscale_Phys2 = mean(AG24hit+AG25slap) , by(ID)
gen		AGscale_Phys = AGscale2/2	
lab var AGscale_Phys "Physical Aggression Scale"

* All Perpetration
alpha 	AG19face AG22shout AG23no AG24hit AG25slap
egen 	AGscale_Perp2 = mean(AG19face+AG22shout+AG23no+AG24hit+AG25slap) ///
		, by(ID)
gen		AGscale_Perp = AGscale2/5	
lab var AGscale_Perp "All Perpetration Aggression Scale"

* All Victimizations
alpha 	AG18crit AG20back AG21insult AG26obj
egen 	AGscale_Victim2 = mean(AG18crit+AG20back+AG21insult+AG26obj) , by(ID)
gen		AGscale_Victim = AGscale2/4	
lab var AGscale_Victim "All Victim of Aggression Scale"



****************************************************************
// #2b - Create Binary for Sub-Agression Items
****************************************************************

egen 		BAG_Verbal = total(AG19+AG22+AG23), by(ID)
lab var		BAG_Verbal "High Vebal Aggression"
tab			BAG_Verbal, m
recode		BAG_Verbal 6/14 = 1 	0/5 = 0
lab values 	BAG_Verbal yesno
tab 		BAG_Verbal, m

egen 		BAG_Physical = total(AG24hit+AG25slap), by(ID)
lab var		BAG_Physical "High Physical Aggression"
tab			BAG_Physical, m
recode		BAG_Physical 3/12 = 1 	0/2 = 0
lab values 	BAG_Physical yesno
tab 		BAG_Physical, m

egen 		BAG_Perp = total(AG19face+AG22shout+AG23no+AG24hit+AG25slap), by(ID)
lab var		BAG_Perp "High Perpetration"
tab			BAG_Perp, m
recode		BAG_Perp 8/26 = 1 	0/7 = 0
lab values 	BAG_Perp yesno
tab 		BAG_Perp, m

egen 		BAG_Victim = total(AG18crit+AG20back+AG21insult+AG26obj), by(ID)
lab var		BAG_Victim "High Victimization"
tab			BAG_Victim, m
recode		BAG_Victim 8/21 = 1 	0/7 = 0
lab values 	BAG_Victim yesno
tab 		BAG_Victim, m

tab1		BAG*, m

	

*Drop unneccessary vars
drop 	SRscale2 HCscale2 AGscale2 AGscale_Verbal2 AGscale_Phys2 ///
		AGscale_Perp2 AGscale_Victim2

		
*Save Data
compress
label 	data "ers2-03-w_scales.dta | Scales Created `prj' | `dte'"
note: 	ers2-03-w_scales-long | Scales Created | `tag'
datasignature set, reset
saveold "- Data\ers2-03-w_scales-long", replace



****************************************************************
// #4 - Create vars for total challenging and increasing competetive ability
		*In Wide Dataset
****************************************************************


/////////////////////////////////////////////////////////////////////////
//  Make a Wide Dataset and Save //
/////////////////////////////////////////////////////////////////////////
drop 	SRscale AGscale HCscale

reshape wide session roundscript lastact outcome ///
		reptotal reptotalA scoreinc challenge  ///
		latino race age yrschool major lowcost ///
		female timeblk SR* HC* AG*, ///
		i(ID) j(period) 

**Resort alphabetically to drop unneccessary vars
aorder		
drop 	age1-age34 latino1-latino34 female1-female34  lowcost1-lowcost34 ///
		major1-major34 yrschool1-yrschool34 ///
		race1-race34 roundscript1-roundscript34 session1-session34  ///
		
		

egen	chaltot=rowtotal(challenge*)
lab var	chaltot "Challenge Total"
tab 	chaltot, m

egen	sinctot=rowtotal(scoreinc*)
lab var	sinctot "Score Inc Total"
tab		sinctot, m


clonevar	female_=female35
clonevar	lowcost_=lowcost35

**Save and Label Data

compress
label 	data "ers2-03-w_scales.dta | Scales Created `prj' | `dte'"
note: 	ers2-03-w_scales-wide | Scales Created | `tag'
datasignature set, reset
saveold "- Data\ers2-03-w_scales-wide", replace



log close
exit


NOTES:


. * Baumeister Self-Regulation Questions
. alpha SR*, gen(SRscale) detail item label

Test scale = mean(unstandardized items)

Items        | S  it-cor  ir-cor   ii-cov   alpha   label
-------------+----------------------------------------------------------------
SR1habits    | +   0.524   0.397   .17712   0.774   1 Self-Regulation Q
SR2distract  | +   0.483   0.346   .18056   0.780   2 Self-Regulation Q
SR3innap     | +   0.578   0.415   .16551   0.775   3 Self-Regulation Q
SR4fun       | -   0.625   0.482   .16134   0.764   4 Self-Regulation Q
SR5tempt     | -   0.668   0.564    .1628   0.755   5 Self-Regulation Q
SR6disc      | -   0.519   0.392   .17776   0.775   6 Self-Regulation Q
SR7pleas     | +   0.577   0.459   .17216   0.767   7 Self-Regulation Q
SR8regret    | +   0.684   0.575   .15872   0.752   8 Self-Regulation Q
SR9stop      | +   0.594   0.464   .16794   0.766   9 Self-Regulation Q
SR10act      | +   0.602   0.473   .16703   0.765   10 Self-Regulation Q
-------------+----------------------------------------------------------------
Test scale   |                     .16909   0.786   mean(unstandardized items)
------------------------------------------------------------------------------



*****


. * Honor Code Items
. alpha HC*, gen(HCscale) detail item label

Test scale = mean(unstandardized items)

Items        | S  it-cor  ir-cor   ii-cov   alpha   label
-------------+----------------------------------------------------------------
HC11force    | +   0.539   0.429   .18468   0.719   11 Honor Code Q
HC12tough    | +   0.755   0.588   .12787   0.658   12 Honor Code Q
HC13even     | +   0.676   0.486   .14522   0.691   13 Honor Code Q
HC14fair     | +   0.630   0.444   .15588   0.703   14 Honor Code Q
HC15aggr     | +   0.581   0.365   .16381   0.727   15 Honor Code Q
HC16intim    | +   0.752   0.562    .1251   0.667   16 Honor Code Q
-------------+----------------------------------------------------------------
Test scale   |                     .15043   0.733   mean(unstandardized items)
------------------------------------------------------------------------------



*****

. * Experience of Aggressive Interactions
. alpha AG*, gen(AGscale) detail item label

Test scale = mean(unstandardized items)

Items        | S  it-cor  ir-cor   ii-cov   alpha   label
-------------+----------------------------------------------------------------
AG17angry    | +   0.392   0.294   .22736   0.769   17 Aggression Q
AG18crit     | +   0.580   0.491   .20902   0.751   18 Aggression Q
AG19face     | +   0.492   0.385   .21513   0.760   19 Aggression Q
AG20back     | +   0.506   0.328   .21164   0.772   20 Agression Q
AG21insult   | +   0.815   0.702   .14815   0.708   21 Aggression Q
AG22shout    | +   0.812   0.694   .14731   0.710   22 Aggression Q
AG23no       | +   0.354   0.188   .22574   0.784   23 Aggression Q
AG24hit      | +   0.680   0.562   .18477   0.737   24 Aggression Q
AG25slap     | +   0.326   0.268   .23727   0.773   25 Aggression Q
AG26obj      | +   0.682   0.575   .18923   0.738   26 Aggression Q
-------------+----------------------------------------------------------------
Test scale   |                     .19956   0.772   mean(unstandardized items)
------------------------------------------------------------------------------

