capture log close
log using ers2-models-01-descriptives, replace text

// Descriptive Statistics
// ERS2 - Escalation Study # 2

version 	13.1
clear 		all
macro drop 	_all
set more 	off
set 		linesize 80

local pgm "ers2-models-01-descriptives"
local prj "ERS2 - Escalation Study 2"
local dte "2014-04-06"
local who "trenton mize"
local tag "`pgm' `who' `dte'"


* Long Dataset 
use "- Data\ers2-03-w_scales-long", clear


****************************************************************
// #1 - Descriptive Statistics
****************************************************************

*Raw Totals for Challenging and Increasing Competitive Ability
local dvs "challenge scoreinc"
foreach v in `dvs' {
		di "Hi Cost Condition"
		sum `v' if lowcost==0
		di "Low Cost Condition"
		sum `v' if lowcost==1
		di "Partner Aggressive Last Interaction"
		sum `v' if lastact==1
		di "Partner NOT Aggressive Last Interaction"
		sum `v' if lastact==0
		}

**Charts and Tables are created in ers2-tables_graphs.xlsx		
tabstat challenge if lowcost==1, by(lastact) stat(mean sd n)
tabstat challenge if lowcost==0, by(lastact) stat(mean sd n)	

tabstat scoreinc  if lowcost==1, by(lastact) stat(mean sd n)
tabstat scoreinc  if lowcost==0, by(lastact) stat(mean sd n)	

tabstat	challenge if  scoreinc==1 & lowcost==0, by(lastact) stat(mean sd n)
tabstat	challenge if  scoreinc==0 & lowcost==0, by(lastact) stat(mean sd n)

tabstat	challenge if  scoreinc==1 & lowcost==1, by(lastact) stat(mean sd n)
tabstat	challenge if  scoreinc==0 & lowcost==1, by(lastact) stat(mean sd n)


**Challenging and Increasing CA by Partner's Reputation		
tabstat challenge if 	lowcost==0, by(reptotal) stat(mean sd n)
tabstat challenge if 	lowcost==1, by(reptotal) stat(mean sd n)
tabstat scoreinc  if 	lowcost==0, by(reptotal) stat(mean sd n)
tabstat scoreinc  if 	lowcost==1, by(reptotal) stat(mean sd n)



****************************************************************
// #2 - Time Effects
****************************************************************

tabstat challenge, by(timeblk) stat(mean sd n)
tabstat scoreinc, by(timeblk) stat(mean sd n)

tabstat challenge if lowcost==1, by(timeblk) stat(mean sd n)
tabstat challenge if lowcost==0, by(timeblk) stat(mean sd n)
tabstat scoreinc  if lowcost==1, by(timeblk) stat(mean sd n)
tabstat scoreinc  if lowcost==0, by(timeblk) stat(mean sd n)

tabstat challenge if lastact==1, by(timeblk) stat(mean sd n)
tabstat challenge if lastact==0, by(timeblk) stat(mean sd n)
tabstat scoreinc  if lastact==1, by(timeblk) stat(mean sd n)
tabstat scoreinc  if lastact==0, by(timeblk) stat(mean sd n)

tabstat challenge if lastact==1 & lowcost==0, by(timeblk) stat(mean sd n)
tabstat challenge if lastact==0 & lowcost==0, by(timeblk) stat(mean sd n)
tabstat challenge if lastact==1 & lowcost==1, by(timeblk) stat(mean sd n)
tabstat challenge if lastact==0 & lowcost==1, by(timeblk) stat(mean sd n)

tabstat scoreinc if lastact==1 & lowcost==0, by(timeblk) stat(mean sd n)
tabstat scoreinc if lastact==0 & lowcost==0, by(timeblk) stat(mean sd n)
tabstat scoreinc if lastact==1 & lowcost==1, by(timeblk) stat(mean sd n)
tabstat scoreinc if lastact==0 & lowcost==1, by(timeblk) stat(mean sd n)



****************************************************************
// #3 - Estimate unconditional models to get SEs for figures
****************************************************************

*	Looking at Condition X Partner Aggression
xtset ID

xtlogit challenge i.lowcost##i.lastact, nolog or 
mtable, at(lowcost=(0 1) lastact=(0 1)) stat(est se) predict(pu0)

xtlogit scoreinc i.lowcost##i.lastact, nolog or 
mtable, at(lowcost=(0 1) lastact=(0 1)) stat(est se) predict(pu0)



****************************************************************
// #4 - Supplementary Analyses
****************************************************************

tabstat challenge if lowcost==1 & scoreinc==1, by(lastact) stat(mean sd n)
tabstat challenge if lowcost==0 & scoreinc==1, by(lastact) stat(mean sd n)

tabstat challenge if lowcost==1 & scoreinc==0, by(lastact) stat(mean sd n)
tabstat challenge if lowcost==0 & scoreinc==0, by(lastact) stat(mean sd n)


**Calculate basic correlations b/w Survey Scales and Behavior
pwcorr 	challenge scoreinc SRscale HCscale AGscale, sig



* Wide Dataset 
use "- Data\ers2-03-w_scales-wide", clear

// # - Descriptives by Condition

*Raw Totals for Challenging and Increasing Competitive Ability
local dvs "chaltot sinctot"
foreach v in `dvs' {
		di "Hi Cost Condition"
		sum `v' if lowcost_==0
		di "Low Cost Condition"
		sum `v' if lowcost_==1
		}






log close
exit

NOTES:

