capture log close
log using ers2-models-02-logits, replace text

// Descriptive Statistics
// ERS1 - Escalation Study # 2

version 13.1
clear all
macro drop _all
set more off
set linesize 80

local pgm "ers2-models-02-logits"
local prj "ERS2 - Escalation Study 2"
local dte "2015-09-22"
local who "trenton mize"
local tag "`pgm' `who' `dte'"

**Long Dataset
use "- Data\ers2-03-w_scales-long", clear



************************************************************************
// #1 - Multilevel Logit Models: Level 2 Random-Intercept on Participant ID
************************************************************************

xtset 	ID 

*NOTE: Adding a control for reptotal, switched timblk to dummy variables,
*and put hicost and lastact in single model -- all based on reviewer
*comments

*NOTE: Some p-values have been cut in half for reporting in paper
*	because hypotheses are directional, thus using one-tailed
*	tests for predicted effects


// Escalating //
xtlogit scoreinc lowcost lastact reptotal i.timeblk, nolog or
xtlogit scoreinc i.lowcost##i.lastact reptotal i.timeblk, nolog or

// Challenging //
xtlogit challenge lowcost lastact reptotal i.timeblk, nolog or
xtlogit challenge i.lowcost##i.lastact reptotal i.timeblk, nolog or



************************************************************************
// #2 - Interactions - Tested in Pred. Probs
************************************************************************

*NOTE: Need tests of 2nd differences in pred. probs
*	- Can't rely on sig. of interaction coef.

xtlogit challenge i.lowcost##i.lastact reptotal i.timeblk, nolog or
mtable, at(lowcost=(0 1) lastact=(0 1)) stat(est se) post predict(pu0)
*Effect of Aggressive reputations in medium cost condition
mlincom 1 - 2
*Effect of Aggressive reputations in low cost condition
mlincom 3 - 4
*Test of second difference
mlincom (1 - 2) - (3 - 4)



*NOTE: Below is supplementary (not presented in paper)

xtlogit scoreinc i.lowcost##i.lastact reptotal i.timeblk, nolog or
mtable, at(lowcost=(0 1) lastact=(0 1)) stat(est se) post predict(pu0)
*Effect of Aggressive reputations in medium cost condition
mlincom 1 - 2
*Effect of Aggressive reputations in low cost condition
mlincom 3 - 4
*Test of second difference
mlincom (1 - 2) - (3 - 4)



************************************************************************
// #3 - Interaction with Partner Reputation (Appendix S2)
************************************************************************

xtlogit	scoreinc  i.lowcost c.reptotal lastact i.timeblk, nolog or
xtlogit	scoreinc  i.lowcost##c.reptotal lastact i.timeblk, nolog or

xtlogit challenge i.lowcost c.reptotal lastact i.timeblk, nolog or
xtlogit challenge i.lowcost##c.reptotal lastact i.timeblk, nolog or
mtable, at(lowcost=(0 1) reptotal=(0 5)) stat(est se) post predict(pu0)
*Effect of Aggressive reputations in medium cost condition
mlincom 1 - 2
*Effect of Aggressive reputations in low cost condition
mlincom 3 - 4
*Test of second difference
mlincom (1 - 2) - (3 - 4)




************************************************************************
// #4 - Supplementary Analyses:
************************************************************************
**For over time analyses, see the "...graphs.do" file

** Gender Effects Tests (No Main Effects. One Significant Second Diff.
*		With Partner's Last Act)
xtlogit challenge female timeblk, nolog or		
xtlogit scoreinc  female timeblk, nolog or		
	
xtlogit challenge i.female##i.lowcost timeblk, nolog or
mtable, at(lowcost=(0 1) female=(0 1)) post predict(pu0)
mlincom (4 - 3) - (2 - 1)		

xtlogit scoreinc  i.female##i.lowcost timeblk, nolog or		
mtable, at(lowcost=(0 1) female=(0 1)) post predict(pu0)
mlincom (4 - 3) - (2 - 1)

xtlogit challenge i.female##i.lastact timeblk, nolog or	
mtable, at(lastact=(0 1) female=(0 1)) post predict(pu0)
mlincom (4 - 3) - (2 - 1)
	
xtlogit scoreinc  i.female##i.lastact timeblk, nolog or	
mtable, at(lastact=(0 1) female=(0 1)) post predict(pu0)
*Effect of partner aggression for women
mlincom 2 - 1
*Effect of partner aggression for men
mlincom 4 - 3
*2nd Difference
mlincom (4 - 3) - (2 - 1)



************************************************************************
// #4 - Post-test Scales
************************************************************************

**Test for Main Effects and Interactions with scales and partner's last act
** and Condition

*Main Effects (some sig at p<0.10; none at p<0.05)
local ivs "HCscale SRscale BAG_Verbal BAG_Physical BAG_Perp BAG_Victim"
foreach v in `ivs' {
	xtlogit challenge `v' timeblk, nolog or
	xtlogit scoreinc `v' timeblk, nolog or
	}


// Interactions with Condition //
local ivs "HCscale SRscale"
foreach v in `ivs' {
	di _newline(1)
	di in red "// DV: Challenge - IV: `v' //"
	qui xtlogit	challenge  c.`v'##i.lowcost timeblk, nolog or
	mtable, dydx(`v') at(lowcost=(0 1)) post
	mlincom 2 - 1, stat(est se p) 
	di _newline(1)
	di in red "// DV: Scoreinc - IV: `v' //"
	qui xtlogit	scoreinc   c.`v'##i.lowcost timeblk, nolog or
	mtable, dydx(`v') at(lowcost=(0 1)) post
	mlincom 2 - 1, stat(est se p) 
	}
*No significant 2nd differences (interaction effects)

local ivs "BAG_Verbal BAG_Physical BAG_Perp BAG_Victim"
foreach v in `ivs' {
	di _newline(1)
	di in red "// DV: Challenge - IV: `v' //"
	qui xtlogit	challenge  i.`v'##i.lowcost timeblk, nolog or
	mtable, dydx(`v') at(lowcost=(0 1)) post
	mlincom 2 - 1, stat(est se p) 
	di _newline(1)
	di in red "// DV: Scoreinc - IV: `v' //"
	qui xtlogit	scoreinc   i.`v'##i.lowcost timeblk, nolog or
	mtable, dydx(`v') at(lowcost=(0 1)) post
	mlincom 2 - 1, stat(est se p) 
	}	
*Only one marginally sig 2nd difference - breaking it out here to investigate
xtlogit challenge i.BAG_Physical##i.lowcost timeblk, nolog or
mtable, at(BAG_Physical=(0 1) lowcost=(0 1)) post
*Effect of experiencing aggression in medium cost condition
mlincom 2 - 1, stat(est se p)
*Effect of experiencing aggression in low cost condition
mlincom 4 - 3, stat(est se p)
*2nd difference
mlincom (4 - 3) - (2 - 1), stat(est se p)

	
	
// Interactions with Partner Aggression //
local ivs "HCscale SRscale"
foreach v in `ivs' {
	di _newline(1)
	di in red "// DV: Challenge - IV: `v' //"
	qui xtlogit	challenge  c.`v'##i.lastact timeblk, nolog or
	mtable, dydx(`v') at(lastact=(0 1)) post
	mlincom 2 - 1, stat(est se p) 
	di _newline(1)
	di in red "// DV: Scoreinc - IV: `v' //"
	qui xtlogit	scoreinc   c.`v'##i.lastact timeblk, nolog or
	mtable, dydx(`v') at(lastact=(0 1)) post
	mlincom 2 - 1, stat(est se p) 
	}
*No significant 2nd differences (interaction effects)

local ivs "BAG_Verbal BAG_Physical BAG_Perp BAG_Victim"
foreach v in `ivs' {
	di _newline(1)
	di in red "// DV: Challenge - IV: `v' //"
	qui xtlogit	challenge  i.`v'##i.lastact timeblk, nolog or
	mtable, dydx(`v') at(lastact=(0 1)) post
	mlincom 2 - 1, stat(est se p) 
	di _newline(1)
	di in red "// DV: Scoreinc - IV: `v' //"
	qui xtlogit	scoreinc   i.`v'##i.lastact timeblk, nolog or
	mtable, dydx(`v') at(lastact=(0 1)) post
	mlincom 2 - 1, stat(est se p) 
	}	
*Only one sig 2nd difference - breaking it out here to investigate
xtlogit challenge i.BAG_Physical##i.lastact timeblk, nolog or
mtable, at(BAG_Physical=(0 1) lastact=(0 1)) post
*Effect of experiencing aggression in responding to partner aggression
mlincom 2 - 1, stat(est se p)
*Effect of experiencing aggression in responding to partner aggression
mlincom 4 - 3, stat(est se p)
*2nd difference
mlincom (4 - 3) - (2 - 1), stat(est se p)




log close 
exit

NOTES:

* We don't report these, but code is below in case we want it again:

**Interaction with Participant's Sex (no significant interactions)
local ivs "HCscale SRscale"
foreach v in `ivs' {
	xtlogit	challenge  i.female##c.`v' timeblk, nolog or
	xtlogit	scoreinc   i.female##c.`v' timeblk, nolog or
	}


local ivs "BAG_Verbal BAG_Physical BAG_Perp BAG_Victim"
foreach v in `ivs' {
	xtlogit	challenge  i.female##i.`v' timeblk, nolog or
	xtlogit	scoreinc   i.female##i.`v' timeblk, nolog or
	}	

		
